@@ -962,8 +962,7 @@ void MainWindow::readSettings()
      settings.beginGroup( "Time" );
         if( settings.value( "systemTime", "true" ).toBool() == true  )
         {
-            m_controlView->marbleModel()->setClockDateTime( QDateTime::currentDateTime().toUTC() );
-            m_controlView->marbleModel()->setClockSpeed( 1 );
+            /* nothing to do */
         }
         else if( settings.value( "lastSessionTime", "true" ).toBool() == true )
         {
@@ -1417,6 +1416,8 @@ void MainWindow::showMapWizard()
         settings.setValue( "wmsServers", mapWizard->wmsServers() );
         settings.setValue( "staticUrlServers", mapWizard->staticUrlServers() );
     settings.endGroup();
+
+    mapWizard->deleteLater();
 }
 
 void MainWindow::showGoToDialog()
